==> google-cloud-bigquery-datatransfer-3.1.1.tar.gz: google-cloud-bigquery-datatransfer-3.1.1/google/cloud/bigquery_datatransfer_v1/services/data_transfer_service/transports/base.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import abc
import typing
import pkg_resources

from google import auth  # type: ignore
from google.api_core import exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials  # type: ignore

from google.cloud.bigquery_datatransfer_v1.types import datatransfer
from google.cloud.bigquery_datatransfer_v1.types import transfer
from google.protobuf import empty_pb2 as empty  # type: ignore


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bigquery-datatransfer",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class DataTransferServiceTransport(abc.ABC):
    """Abstract transport class for DataTransferService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self,
        *,
        host: str = "bigquerydatatransfer.googleapis.com",
        credentials: credentials.Credentials = None,
        credentials_file: typing.Optional[str] = None,
        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
        quota_project_id: typing.Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]): The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scope (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        # Save the scopes.
        self._scopes = scopes or self.AUTH_SCOPES

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = auth.load_credentials_from_file(
                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = auth.default(
                scopes=self._scopes, quota_project_id=quota_project_id
            )

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_data_source: gapic_v1.method.wrap_method(
                self.get_data_source,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_data_sources: gapic_v1.method.wrap_method(
                self.list_data_sources,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.create_transfer_config: gapic_v1.method.wrap_method(
                self.create_transfer_config,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.update_transfer_config: gapic_v1.method.wrap_method(
                self.update_transfer_config,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_transfer_config: gapic_v1.method.wrap_method(
                self.delete_transfer_config,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.get_transfer_config: gapic_v1.method.wrap_method(
                self.get_transfer_config,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_configs: gapic_v1.method.wrap_method(
                self.list_transfer_configs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.schedule_transfer_runs: gapic_v1.method.wrap_method(
                self.schedule_transfer_runs,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.start_manual_transfer_runs: gapic_v1.method.wrap_method(
                self.start_manual_transfer_runs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_transfer_run: gapic_v1.method.wrap_method(
                self.get_transfer_run,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.delete_transfer_run: gapic_v1.method.wrap_method(
                self.delete_transfer_run,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_runs: gapic_v1.method.wrap_method(
                self.list_transfer_runs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_logs: gapic_v1.method.wrap_method(
                self.list_transfer_logs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.check_valid_creds: gapic_v1.method.wrap_method(
                self.check_valid_creds,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
        }

    @property
    def get_data_source(
        self,
    ) -> typing.Callable[
        [datatransfer.GetDataSourceRequest],
        typing.Union[
            datatransfer.DataSource, typing.Awaitable[datatransfer.DataSource]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_data_sources(
        self,
    ) -> typing.Callable[
        [datatransfer.ListDataSourcesRequest],
        typing.Union[
            datatransfer.ListDataSourcesResponse,
            typing.Awaitable[datatransfer.ListDataSourcesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_transfer_config(
        self,
    ) -> typing.Callable[
        [datatransfer.CreateTransferConfigRequest],
        typing.Union[
            transfer.TransferConfig, typing.Awaitable[transfer.TransferConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_transfer_config(
        self,
    ) -> typing.Callable[
        [datatransfer.UpdateTransferConfigRequest],
        typing.Union[
            transfer.TransferConfig, typing.Awaitable[transfer.TransferConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_transfer_config(
        self,
    ) -> typing.Callable[
        [datatransfer.DeleteTransferConfigRequest],
        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_transfer_config(
        self,
    ) -> typing.Callable[
        [datatransfer.GetTransferConfigRequest],
        typing.Union[
            transfer.TransferConfig, typing.Awaitable[transfer.TransferConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_configs(
        self,
    ) -> typing.Callable[
        [datatransfer.ListTransferConfigsRequest],
        typing.Union[
            datatransfer.ListTransferConfigsResponse,
            typing.Awaitable[datatransfer.ListTransferConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def schedule_transfer_runs(
        self,
    ) -> typing.Callable[
        [datatransfer.ScheduleTransferRunsRequest],
        typing.Union[
            datatransfer.ScheduleTransferRunsResponse,
            typing.Awaitable[datatransfer.ScheduleTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def start_manual_transfer_runs(
        self,
    ) -> typing.Callable[
        [datatransfer.StartManualTransferRunsRequest],
        typing.Union[
            datatransfer.StartManualTransferRunsResponse,
            typing.Awaitable[datatransfer.StartManualTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transfer_run(
        self,
    ) -> typing.Callable[
        [datatransfer.GetTransferRunRequest],
        typing.Union[transfer.TransferRun, typing.Awaitable[transfer.TransferRun]],
    ]:
        raise NotImplementedError()

    @property
    def delete_transfer_run(
        self,
    ) -> typing.Callable[
        [datatransfer.DeleteTransferRunRequest],
        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_runs(
        self,
    ) -> typing.Callable[
        [datatransfer.ListTransferRunsRequest],
        typing.Union[
            datatransfer.ListTransferRunsResponse,
            typing.Awaitable[datatransfer.ListTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_logs(
        self,
    ) -> typing.Callable[
        [datatransfer.ListTransferLogsRequest],
        typing.Union[
            datatransfer.ListTransferLogsResponse,
            typing.Awaitable[datatransfer.ListTransferLogsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def check_valid_creds(
        self,
    ) -> typing.Callable[
        [datatransfer.CheckValidCredsRequest],
        typing.Union[
            datatransfer.CheckValidCredsResponse,
            typing.Awaitable[datatransfer.CheckValidCredsResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("DataTransferServiceTransport",)

==> google-cloud-bigquery-datatransfer-3.2.0.tar.gz: google-cloud-bigquery-datatransfer-3.2.0/google/cloud/bigquery_datatransfer_v1/services/data_transfer_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import packaging.version
import pkg_resources

import google.auth  # type: ignore
import google.api_core  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore

from google.cloud.bigquery_datatransfer_v1.types import datatransfer
from google.cloud.bigquery_datatransfer_v1.types import transfer
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bigquery-datatransfer",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()

try:
    # google.auth.__version__ was added in 1.26.0
    _GOOGLE_AUTH_VERSION = google.auth.__version__
except AttributeError:
    try:  # try pkg_resources if it is available
        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
        _GOOGLE_AUTH_VERSION = None

_API_CORE_VERSION = google.api_core.__version__


class DataTransferServiceTransport(abc.ABC):
    """Abstract transport class for DataTransferService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "bigquerydatatransfer.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)

        # Save the scopes.
        self._scopes = scopes or self.AUTH_SCOPES

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # Save the credentials.
        self._credentials = credentials

    # TODO(busunkim): These two class methods are in the base transport
    # to avoid duplicating code across the transport classes. These functions
    # should be deleted once the minimum required versions of google-api-core
    # and google-auth are increased.

    # TODO: Remove this function once google-auth >= 1.25.0 is required
    @classmethod
    def _get_scopes_kwargs(
        cls, host: str, scopes: Optional[Sequence[str]]
    ) -> Dict[str, Optional[Sequence[str]]]:
        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""

        scopes_kwargs = {}

        if _GOOGLE_AUTH_VERSION and (
            packaging.version.parse(_GOOGLE_AUTH_VERSION)
            >= packaging.version.parse("1.25.0")
        ):
            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
        else:
            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}

        return scopes_kwargs

    # TODO: Remove this function once google-api-core >= 1.26.0 is required
    @classmethod
    def _get_self_signed_jwt_kwargs(
        cls, host: str, scopes: Optional[Sequence[str]]
    ) -> Dict[str, Union[Optional[Sequence[str]], str]]:
        """Returns kwargs to pass to grpc_helpers.create_channel depending on the google-api-core version"""

        self_signed_jwt_kwargs: Dict[str, Union[Optional[Sequence[str]], str]] = {}

        if _API_CORE_VERSION and (
            packaging.version.parse(_API_CORE_VERSION)
            >= packaging.version.parse("1.26.0")
        ):
            self_signed_jwt_kwargs["default_scopes"] = cls.AUTH_SCOPES
            self_signed_jwt_kwargs["scopes"] = scopes
            self_signed_jwt_kwargs["default_host"] = cls.DEFAULT_HOST
        else:
            self_signed_jwt_kwargs["scopes"] = scopes or cls.AUTH_SCOPES

        return self_signed_jwt_kwargs

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_data_source: gapic_v1.method.wrap_method(
                self.get_data_source,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_data_sources: gapic_v1.method.wrap_method(
                self.list_data_sources,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.create_transfer_config: gapic_v1.method.wrap_method(
                self.create_transfer_config,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.update_transfer_config: gapic_v1.method.wrap_method(
                self.update_transfer_config,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.delete_transfer_config: gapic_v1.method.wrap_method(
                self.delete_transfer_config,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.get_transfer_config: gapic_v1.method.wrap_method(
                self.get_transfer_config,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_configs: gapic_v1.method.wrap_method(
                self.list_transfer_configs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.schedule_transfer_runs: gapic_v1.method.wrap_method(
                self.schedule_transfer_runs,
                default_timeout=30.0,
                client_info=client_info,
            ),
            self.start_manual_transfer_runs: gapic_v1.method.wrap_method(
                self.start_manual_transfer_runs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_transfer_run: gapic_v1.method.wrap_method(
                self.get_transfer_run,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.delete_transfer_run: gapic_v1.method.wrap_method(
                self.delete_transfer_run,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_runs: gapic_v1.method.wrap_method(
                self.list_transfer_runs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.list_transfer_logs: gapic_v1.method.wrap_method(
                self.list_transfer_logs,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.check_valid_creds: gapic_v1.method.wrap_method(
                self.check_valid_creds,
                default_retry=retries.Retry(
                    initial=0.1,
                    maximum=60.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.DeadlineExceeded,
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
        }

    @property
    def get_data_source(
        self,
    ) -> Callable[
        [datatransfer.GetDataSourceRequest],
        Union[datatransfer.DataSource, Awaitable[datatransfer.DataSource]],
    ]:
        raise NotImplementedError()

    @property
    def list_data_sources(
        self,
    ) -> Callable[
        [datatransfer.ListDataSourcesRequest],
        Union[
            datatransfer.ListDataSourcesResponse,
            Awaitable[datatransfer.ListDataSourcesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_transfer_config(
        self,
    ) -> Callable[
        [datatransfer.CreateTransferConfigRequest],
        Union[transfer.TransferConfig, Awaitable[transfer.TransferConfig]],
    ]:
        raise NotImplementedError()

    @property
    def update_transfer_config(
        self,
    ) -> Callable[
        [datatransfer.UpdateTransferConfigRequest],
        Union[transfer.TransferConfig, Awaitable[transfer.TransferConfig]],
    ]:
        raise NotImplementedError()

    @property
    def delete_transfer_config(
        self,
    ) -> Callable[
        [datatransfer.DeleteTransferConfigRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_transfer_config(
        self,
    ) -> Callable[
        [datatransfer.GetTransferConfigRequest],
        Union[transfer.TransferConfig, Awaitable[transfer.TransferConfig]],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_configs(
        self,
    ) -> Callable[
        [datatransfer.ListTransferConfigsRequest],
        Union[
            datatransfer.ListTransferConfigsResponse,
            Awaitable[datatransfer.ListTransferConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def schedule_transfer_runs(
        self,
    ) -> Callable[
        [datatransfer.ScheduleTransferRunsRequest],
        Union[
            datatransfer.ScheduleTransferRunsResponse,
            Awaitable[datatransfer.ScheduleTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def start_manual_transfer_runs(
        self,
    ) -> Callable[
        [datatransfer.StartManualTransferRunsRequest],
        Union[
            datatransfer.StartManualTransferRunsResponse,
            Awaitable[datatransfer.StartManualTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transfer_run(
        self,
    ) -> Callable[
        [datatransfer.GetTransferRunRequest],
        Union[transfer.TransferRun, Awaitable[transfer.TransferRun]],
    ]:
        raise NotImplementedError()

    @property
    def delete_transfer_run(
        self,
    ) -> Callable[
        [datatransfer.DeleteTransferRunRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_runs(
        self,
    ) -> Callable[
        [datatransfer.ListTransferRunsRequest],
        Union[
            datatransfer.ListTransferRunsResponse,
            Awaitable[datatransfer.ListTransferRunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_transfer_logs(
        self,
    ) -> Callable[
        [datatransfer.ListTransferLogsRequest],
        Union[
            datatransfer.ListTransferLogsResponse,
            Awaitable[datatransfer.ListTransferLogsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def check_valid_creds(
        self,
    ) -> Callable[
        [datatransfer.CheckValidCredsRequest],
        Union[
            datatransfer.CheckValidCredsResponse,
            Awaitable[datatransfer.CheckValidCredsResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("DataTransferServiceTransport",)
